@@ -25,7 +25,7 @@
 #include <unistd.h>
 
 #include <glib.h>
-#include <glib/gi18n.h>
+#include <glib/gi18n-lib.h>
 #include <gdk/gdkkeysyms.h>
 #include <gtk/gtk.h>
 
@@ -78,7 +78,6 @@ struct GvcMixerDialogPrivate
         GtkWidget       *click_feedback_button;
         GtkWidget       *audible_bell_button;
         GtkSizeGroup    *size_group;
-        GtkSizeGroup    *apps_size_group;
 
         gdouble          last_input_peak;
         guint            num_apps;
@@ -121,7 +120,7 @@ static void     bar_set_stream              (GvcMixerDialog      *dialog,
 static void     on_adjustment_value_changed (GtkAdjustment  *adjustment,
                                              GvcMixerDialog *dialog);
 
-G_DEFINE_TYPE (GvcMixerDialog, gvc_mixer_dialog, GTK_TYPE_DIALOG)
+G_DEFINE_TYPE (GvcMixerDialog, gvc_mixer_dialog, GTK_TYPE_VBOX)
 
 static void
 update_default_input (GvcMixerDialog *dialog)
@@ -926,18 +925,15 @@ save_bar_for_stream (GvcMixerDialog *dialog,
 
 static GtkWidget *
 create_bar (GvcMixerDialog *dialog,
-            GtkSizeGroup   *size_group,
             gboolean        symmetric)
 {
         GtkWidget *bar;
 
         bar = gvc_channel_bar_new ();
         gtk_widget_set_sensitive (bar, FALSE);
-        if (size_group != NULL) {
-                gvc_channel_bar_set_size_group (GVC_CHANNEL_BAR (bar),
-                                                size_group,
-                                                symmetric);
-        }
+        gvc_channel_bar_set_size_group (GVC_CHANNEL_BAR (bar),
+                                        dialog->priv->size_group,
+                                        symmetric);
         gvc_channel_bar_set_orientation (GVC_CHANNEL_BAR (bar),
                                          GTK_ORIENTATION_HORIZONTAL);
         gvc_channel_bar_set_show_mute (GVC_CHANNEL_BAR (bar),
@@ -949,6 +945,31 @@ create_bar (GvcMixerDialog *dialog,
         return bar;
 }
 
+static GtkWidget *
+create_app_bar (GvcMixerDialog *dialog,
+                const char     *name,
+                const char     *icon_name)
+{
+        GtkWidget *bar;
+
+        bar = create_bar (dialog, FALSE);
+        gvc_channel_bar_set_ellipsize (GVC_CHANNEL_BAR (bar), TRUE);
+        gvc_channel_bar_set_icon_name (GVC_CHANNEL_BAR (bar), icon_name);
+        if (name == NULL || strchr (name, '_') == NULL) {
+                gvc_channel_bar_set_name (GVC_CHANNEL_BAR (bar), name);
+        } else {
+                char **tokens, *escaped;
+
+                tokens = g_strsplit (name, "_", -1);
+                escaped = g_strjoinv ("__", tokens);
+                g_strfreev (tokens);
+                gvc_channel_bar_set_name (GVC_CHANNEL_BAR (bar), escaped);
+                g_free (escaped);
+        }
+
+        return bar;
+}
+
 static void
 bar_set_stream (GvcMixerDialog *dialog,
                 GtkWidget      *bar,
@@ -1058,23 +1079,9 @@ add_stream (GvcMixerDialog *dialog,
                    && g_strcmp0 (id, "org.PulseAudio.pavucontrol") != 0) {
                 const char *name;
 
-                bar = create_bar (dialog, dialog->priv->apps_size_group, FALSE);
-
                 name = gvc_mixer_stream_get_name (stream);
-                if (name == NULL || strchr (name, '_') == NULL) {
-                        gvc_channel_bar_set_name (GVC_CHANNEL_BAR (bar), name);
-                } else {
-                        char **tokens, *escaped;
-
-                        tokens = g_strsplit (name, "_", -1); 
-                        escaped = g_strjoinv ("__", tokens);
-                        g_strfreev (tokens);
-                        gvc_channel_bar_set_name (GVC_CHANNEL_BAR (bar), escaped);
-                        g_free (escaped);
-                }
-
-                gvc_channel_bar_set_icon_name (GVC_CHANNEL_BAR (bar),
-                                               gvc_mixer_stream_get_icon_name (stream));
+                bar = create_app_bar (dialog, name,
+                                      gvc_mixer_stream_get_icon_name (stream));
 
                 gtk_box_pack_start (GTK_BOX (dialog->priv->applications_box), bar, FALSE, FALSE, 12);
                 dialog->priv->num_apps++;
@@ -1520,13 +1527,12 @@ on_test_speakers_clicked (GvcComboBox *widget,
                  profile->profile, gvc_mixer_card_get_name (card));
 
         title = g_strdup_printf (_("Speaker Testing for %s"), gvc_mixer_card_get_name (card));
+        // FIXME
+        // set parent dialogue
+        // https://bugzilla.gnome.org/show_bug.cgi?id=621940
         d = gtk_dialog_new_with_buttons (title,
-                                         GTK_WINDOW (dialog),
-                                         GTK_DIALOG_MODAL |
-#if !GTK_CHECK_VERSION (2, 21, 8)
-                                         GTK_DIALOG_NO_SEPARATOR |
-#endif
-                                         GTK_DIALOG_DESTROY_WITH_PARENT,
+                                         NULL,
+                                         GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
                                          NULL);
         g_free (title);
         speaker_test = gvc_speaker_test_new (dialog->priv->mixer_control,
@@ -1671,32 +1677,6 @@ create_cards_treeview (GvcMixerDialog *dialog,
         return treeview;
 }
 
-static const guint tab_accel_keys[] = {
-        GDK_1, GDK_2, GDK_3, GDK_4, GDK_5
-};
-
-static void
-dialog_accel_cb (GtkAccelGroup    *accelgroup,
-                 GObject          *object,
-                 guint             key,
-                 GdkModifierType   mod,
-                 GvcMixerDialog   *self)
-{
-        gint num = -1;
-        gint i;
-
-        for (i = 0; i < G_N_ELEMENTS (tab_accel_keys); i++) {
-                if (tab_accel_keys[i] == key) {
-                        num = i;
-                        break;
-                }
-        }
-
-        if (num != -1) {
-                gtk_notebook_set_current_page (GTK_NOTEBOOK (self->priv->notebook), num);
-        }
-}
-
 static GObject *
 gvc_mixer_dialog_constructor (GType                  type,
                               guint                  n_construct_properties,
@@ -1716,16 +1696,12 @@ gvc_mixer_dialog_constructor (GType                  type,
         GvcMixerStream   *stream;
         GvcMixerCard     *card;
         GtkTreeSelection *selection;
-        GtkAccelGroup    *accel_group;
-        GClosure         *closure;
-        gint             i;
 
         object = G_OBJECT_CLASS (gvc_mixer_dialog_parent_class)->constructor (type, n_construct_properties, construct_params);
 
         self = GVC_MIXER_DIALOG (object);
-        gtk_dialog_add_button (GTK_DIALOG (self), "gtk-close", GTK_RESPONSE_OK);
 
-        main_vbox = gtk_dialog_get_content_area (GTK_DIALOG (self));
+        main_vbox = GTK_WIDGET (self);
         gtk_box_set_spacing (GTK_BOX (main_vbox), 2);
 
         gtk_container_set_border_width (GTK_CONTAINER (self), 6);
@@ -1737,7 +1713,7 @@ gvc_mixer_dialog_constructor (GType                  type,
         gtk_box_pack_start (GTK_BOX (main_vbox),
                             alignment,
                             FALSE, FALSE, 0);
-        self->priv->output_bar = create_bar (self, self->priv->size_group, TRUE);
+        self->priv->output_bar = create_bar (self, TRUE);
         gvc_channel_bar_set_name (GVC_CHANNEL_BAR (self->priv->output_bar),
                                   _("_Output volume: "));
         gtk_widget_set_sensitive (self->priv->output_bar, FALSE);
@@ -1750,23 +1726,6 @@ gvc_mixer_dialog_constructor (GType                  type,
                             TRUE, TRUE, 0);
         gtk_container_set_border_width (GTK_CONTAINER (self->priv->notebook), 5);
 
-        /* Set up accels (borrowed from Empathy) */
-        accel_group = gtk_accel_group_new ();
-        gtk_window_add_accel_group (GTK_WINDOW (self), accel_group);
-
-        for (i = 0; i < G_N_ELEMENTS (tab_accel_keys); i++) {
-                closure =  g_cclosure_new (G_CALLBACK (dialog_accel_cb),
-                                           self,
-                                           NULL);
-                gtk_accel_group_connect (accel_group,
-                                         tab_accel_keys[i],
-                                         GDK_MOD1_MASK,
-                                         0,
-                                         closure);
-        }
-
-        g_object_unref (accel_group);
-
         /* Effects page */
         self->priv->sound_effects_box = gtk_vbox_new (FALSE, 6);
         gtk_container_set_border_width (GTK_CONTAINER (self->priv->sound_effects_box), 12);
@@ -1775,7 +1734,7 @@ gvc_mixer_dialog_constructor (GType                  type,
                                   self->priv->sound_effects_box,
                                   label);
 
-        self->priv->effects_bar = create_bar (self, self->priv->size_group, TRUE);
+        self->priv->effects_bar = create_bar (self, TRUE);
         gvc_channel_bar_set_name (GVC_CHANNEL_BAR (self->priv->effects_bar),
                                   _("_Alert volume: "));
         gtk_widget_set_sensitive (self->priv->effects_bar, FALSE);
@@ -1838,7 +1797,7 @@ gvc_mixer_dialog_constructor (GType                  type,
                                   self->priv->input_box,
                                   label);
 
-        self->priv->input_bar = create_bar (self, self->priv->size_group, TRUE);
+        self->priv->input_bar = create_bar (self, TRUE);
         gvc_channel_bar_set_name (GVC_CHANNEL_BAR (self->priv->input_bar),
                                   _("_Input volume: "));
         gvc_channel_bar_set_low_icon_name (GVC_CHANNEL_BAR (self->priv->input_bar),
@@ -2067,7 +2026,6 @@ gvc_mixer_dialog_init (GvcMixerDialog *dialog)
         dialog->priv = GVC_MIXER_DIALOG_GET_PRIVATE (dialog);
         dialog->priv->bars = g_hash_table_new (NULL, NULL);
         dialog->priv->size_group = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
-        dialog->priv->apps_size_group = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
 }
 
 static void
@@ -2089,9 +2047,6 @@ gvc_mixer_dialog_new (GvcMixerControl *control)
 {
         GObject *dialog;
         dialog = g_object_new (GVC_TYPE_MIXER_DIALOG,
-                               "icon-name", "multimedia-volume-control",
-                               "title", _("Sound Preferences"),
-                               "has-separator", FALSE,
                                "mixer-control", control,
                                NULL);
         return GVC_MIXER_DIALOG (dialog);
