@@ -131,9 +131,9 @@ popup_dock (GvcStreamStatusIcon *icon,
         monitor_num = gdk_screen_get_monitor_at_point (screen, area.x, area.y);
         gdk_screen_get_monitor_geometry (screen, monitor_num, &monitor);
 
-        gtk_container_foreach (GTK_CONTAINER (icon->priv->dock), 
+        gtk_container_foreach (GTK_CONTAINER (icon->priv->dock),
                                (GtkCallback) gtk_widget_show_all, NULL);
-        gtk_widget_size_request (icon->priv->dock, &dock_req);
+        gtk_widget_get_preferred_size (icon->priv->dock, &dock_req, NULL);
 
         if (orientation == GTK_ORIENTATION_VERTICAL) {
                 if (area.x + area.width + dock_req.width <= monitor.x + monitor.width) {
@@ -172,7 +172,7 @@ popup_dock (GvcStreamStatusIcon *icon,
         /* grab focus */
         gtk_grab_add (icon->priv->dock);
 
-        if (gdk_pointer_grab (icon->priv->dock->window, TRUE,
+        if (gdk_pointer_grab (gtk_widget_get_window (icon->priv->dock), TRUE,
                               GDK_BUTTON_PRESS_MASK | GDK_BUTTON_RELEASE_MASK |
                               GDK_POINTER_MOTION_MASK | GDK_SCROLL_MASK, NULL, NULL,
                               time)
@@ -182,7 +182,7 @@ popup_dock (GvcStreamStatusIcon *icon,
                 return FALSE;
         }
 
-        if (gdk_keyboard_grab (icon->priv->dock->window, TRUE, time) != GDK_GRAB_SUCCESS) {
+        if (gdk_keyboard_grab (gtk_widget_get_window (icon->priv->dock), TRUE, time) != GDK_GRAB_SUCCESS) {
                 display = gtk_widget_get_display (icon->priv->dock);
                 gdk_display_pointer_ungrab (display, time);
                 gtk_grab_remove (icon->priv->dock);
@@ -219,7 +219,7 @@ on_menu_activate_open_volume_control (GtkMenuItem *item,
 
         error = NULL;
         gdk_spawn_command_line_on_screen (gtk_widget_get_screen (icon->priv->dock),
-                                          "gnome-volume-control",
+                                          "gnome-control-center sound",
                                           &error);
 
         if (error != NULL) {
@@ -343,7 +343,7 @@ gvc_icon_grab_notify (GvcStreamStatusIcon *icon,
                 return;
         }
 
-        if (!GTK_WIDGET_HAS_GRAB (icon->priv->dock)) {
+        if (!gtk_widget_has_grab (icon->priv->dock)) {
                 return;
         }
 
@@ -377,7 +377,7 @@ on_dock_key_release (GtkWidget           *widget,
                      GdkEventKey         *event,
                      GvcStreamStatusIcon *icon)
 {
-        if (event->keyval == GDK_Escape) {
+        if (event->keyval == GDK_KEY_Escape) {
                 popdown_dock (icon);
                 return TRUE;
         }
