@@ -1087,9 +1087,6 @@ file_properties_cb (GtkAction *action,
 					      GTK_DIALOG_DESTROY_WITH_PARENT,
 					      GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE, NULL);
 	g_free (title);
-#if !GTK_CHECK_VERSION (2, 21, 8)
-	gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
-#endif
 	gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
 	gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
 	gtk_box_set_spacing (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dialog))), 2);
